Learn R Programming

rankUncertainty (version 1.0.2.0)

canonicalize: Compute a canonical representation of an interval order

Description

This functions generates a set of intervals with distinct endpoints such that running any of the functions in this package on the return value gives the same answer as running those functions on the input.

Usage

canonicalize(intervals)

Arguments

intervals

data frame (see generateIntervals for the required format)

Value

a data frame in the same format as the input

Details

See section 3.1 of Rising (2021).

References

Rising, Justin (2021). Uncertainty in Ranking. arXiv:2107.03459.

Examples

Run this code
# NOT RUN {
left <- c(0, 0, 0, 1, 2)
right <- c(0, 1, 2, 2, 2)
intervals <- data.frame(left = left, right = right)
toMatrix(intervals)
toMatrix(canonicalize(intervals))
# }

Run the code above in your browser using DataLab