Learn R Programming

rankUncertainty (version 1.0.2.0)

indexIntervals: Generate index intervals for a set of intervals

Description

If we pick one point from each of a set of intervals, the index intervals describe the possible ranks of points in each interval. If this function is given simultaneous 100(1 - alpha)% confidence intervals for a distinct set of parameters, the index intervals are simultaneous 100(1 - alpha)% confidence intervals for the true ranks.

Usage

indexIntervals(intervals)

Arguments

intervals

data frame (see generateIntervals for the required format)

Value

data frame (see generateIntervals for the format)

Details

See section 5.2 of Rising (2021).

References

Rising, Justin (2021). Uncertainty in Ranking. arXiv:2107.03459.

Examples

Run this code
# NOT RUN {
left <- 0:2 * 0.5 + 1
right <- left + 0.75
intervals <- data.frame(left = left, right = right)
indexIntervals(intervals)
# }

Run the code above in your browser using DataLab