Learn R Programming

rankUncertainty (version 1.0.2.0)

lessThan: Compare intervals

Description

Given a data frame representing a set of intervals, return true if row i is less than row j under the order generated by the intervals and false otherwise.

Usage

lessThan(intervals, i, j)

Arguments

intervals

data frame (see generateIntervals for the required format)

i

row index of left-hand side of inequality

j

row index of right-hand side of inequaltiy

Value

Boolean value

Examples

Run this code
# NOT RUN {
left <- 0:2 * 0.5 + 1
right <- left + 0.75
intervals <- data.frame(left = left, right = right)
lessThan(intervals, 1, 2)
lessThan(intervals, 1, 3)
# }

Run the code above in your browser using DataLab