Learn R Programming

rankUncertainty (version 1.0.2.0)

partition: Partition the order generated by a set of intervals

Description

A partition of the order generated by a set of intervals is a partition of their indices with the property the sets can be ordered so that the right endpoint of every interval in a set is less than the left endpoint of any interval in any subsequent set.

Usage

partition(intervals)

Arguments

intervals

data frame (see generateIntervals for the required format)

Value

A list whose entries correspond to sets in the partition

Details

See section 3.2 of Rising (2021).

References

Rising, Justin (2021). Uncertainty in Ranking. arXiv:2107.03459.

Examples

Run this code
# NOT RUN {
left <- sort(c(1:3, 1:3 + 0.1))
right <- left + 0.7
intervals <- data.frame(left = left, right = right)
partition(intervals)
# }

Run the code above in your browser using DataLab