canonicalize: Compute a canonical representation of an interval order
Description
This functions generates a set of intervals with distinct endpoints such that
running any of the functions in this package on the return value gives the
same answer as running those functions on the input.