powered by
Generate a set of intervals with endpoints uniformly distributed between 0 and 1.
generateIntervals(n, sort = FALSE, f = NULL)
number of intervals to generate
if TRUE, sort the output intervals by their left endpoints
transformation to apply to each endpoint
Data frame with columns 'left' and 'right'. It is guaranteed that every value in 'left' is no greater than the corresponding value in 'right'.
# NOT RUN { generateIntervals(10) generateIntervals(20, f = qnorm) generateIntervals(5, TRUE, f = function(x) { x + 1 }) # }
Run the code above in your browser using DataLab