indexIntervals: Generate index intervals for a set of intervals
Description
If we pick one point from each of a set of intervals, the index intervals
describe the possible ranks of points in each interval. If this function is
given simultaneous 100(1 - alpha)% confidence intervals for a distinct set
of parameters, the index intervals are simultaneous 100(1 - alpha)%
confidence intervals for the true ranks.