partition: Partition the order generated by a set of intervals
Description
A partition of the order generated by a set of intervals is a partition of
their indices with the property the sets can be ordered so that the right
endpoint of every interval in a set is less than the left endpoint of any
interval in any subsequent set.